package de.intevation.flys.exports;

import java.io.OutputStream;

import org.w3c.dom.Document;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;


/**
 * An OutGenerator is used to create a collected outputs of a list of Artifacts.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public interface OutGenerator {

    /**
     * Initializes the OutGenerator with meta information which are necessary
     * for the output generation.
     *
     * @param request The incomding request document.
     * @param out     The output stream.
     * @param context The CallContext that provides further information and
     * objects used for the output generation.
     */
    void init(Document request, OutputStream out, CallContext context);

    /**
     * Creates the output of an Artifact and appends that single output to the
     * total output.
     *
     * @param artifact The artifact that provides information and data for the
     * single output.
     * @param attr A document that might contain some attributes used while
     * producing the output.
     */
    void doOut(Artifact artifact, Document attr);

    /**
     * Writes the collected output of all artifacts specified in the
     * <i>request</i> (see init()) document to the OutputStream <i>out</i> (see
     * init()).
     */
    void generate();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
